@@ -6,10 +6,11 @@
 (use-modules (nyacc lang c99 xparser))
 (use-modules (nyacc lang c99 cpp))
 (use-modules (nyacc lang c99 pprint))
+(use-modules (nyacc lang c99 munge))
 (use-modules (nyacc lang c99 util1))
-(use-modules (nyacc lang c99 util2))
 (use-modules (nyacc lang util))
 (use-modules (nyacc lex))
+(use-modules (nyacc util))
 (use-modules (ice-9 pretty-print))
 (use-modules (sxml xpath))
 
@@ -96,28 +97,34 @@
 	      "typedef double hmm_t[3];\n"
 	      "int baz(foo_t (*baz)(hmm_t y));\n"
 	      ))
-       (xcode (string-append
-	      "typedef struct { int x; } foo_t;\n"
+       (code (string-append
+	      "typedef struct foo foo_t;\n"
 	      "foo_t *y;\n"
-	      ;; expand as
-	      ;; 1) struct struct__foo_t *y;
-	      ;; 2) void *y;
+	      "foo_t z;\n"
 	      ))
+       (code "int x = 0x00000000FFFFFFFFLLU;")
+       (code (string-append
+	      "typedef struct {\n"
+	      "  unsigned int is_bin : 1, is_write : 2;\n"
+	      "  long lineno;"
+	      "} foo_t;\n"
+	      ))
+       (code "double x = 123.4f;")
+       (code "#if L'c'\nint x = 1;\n#endif\n")
        (indx 2)
-       (tree (parse-string code))
-       ;;(tree (parse-c99x code))
-       ;;(tree (parse-file "zz4.c"))
-       
-       (udict (c99-trans-unit->udict tree))
+       ;;(tree (parse-string code))
+       (tree (parse-file "xxx.c"))
+       ;;(udict (c99-trans-unit->udict tree))
        ;;(ddict (udict-enums->ddict udict))
-       (udecl (udict-ref udict "baz"))
+       ;;(udecl (udict-ref udict "z"))
        ;;(decl (and=> ((sxpath `((decl ,indx))) tree) car))
-       (xdecl (expand-typerefs udecl udict))
+       ;;(xdecl (expand-typerefs udecl udict '((struct . "foo"))))
        )
   ;;(display code)
-  (pp99 udecl)
-  (display "==\n")
-  (pp99 xdecl)
+  (ppsx tree)
+  ;;(ppsx xdecl)
+  ;;(display "==\n")
+  ;;(pp99 xdecl)
   ;;(ppsx mspec)
   ;;(ppsx (expand-typerefs udecl udict '("foo_t")))
   ;;(ppsx ddict)
@@ -127,5 +134,24 @@
 ;; ex12.c: illustrates removal of comment prefix, offset-8 => offset-2
 ;;(let ((tree (parse-file "exam.d/ex12.c"))) (pp99 tree))
       
+;;(ugly-print (quote `(abc ,@def)))
+
+(define n1570a ;; sec 6.7.8
+  (string-append
+   "typedef signed int t;\n"
+   "typedef int plain;\n"
+   "struct tag {\n"
+   "  unsigned t:4;\n"
+   "  const t:5;\n"
+   "  plain r:5;\n"
+   "};\n"))
+(define n1570b
+  (string-append
+   n1570a
+   "int foo() {\n"
+   "  t f(t (t));\n"
+   "  long t;\n"
+   "  return 1;\n"
+   "};\n"))
 
 ;; --- last line ---
