@@ -224,7 +224,10 @@
 
 ;; generate a lexical analyzer per string
 (define gen-cpp-lexer
-  (make-lexer-generator cpp-mtab #:comm-skipper cpp-comm-skipper))
+  (make-lexer-generator cpp-mtab
+			#:comm-skipper cpp-comm-skipper
+			#:chlit-reader read-c-chlit
+			#:num-reader read-c-num))
 
 ;; @deffn {Procedure} parse-cpp-expr text => tree
 ;; Given a string returns a cpp parse tree.  This is called by
@@ -241,11 +244,12 @@
    (lambda (key fmt . args)
      (apply throw 'cpp-error fmt args))))
 
-;; @deffn {Procedure} eval-cpp-expr tree dict => datum
+;; @deffn {Procedure} eval-cpp-expr tree [options] => datum
 ;; Evaluate a tree produced from @code{parse-cpp-expr}.
-;; The tree passed to this routine is 
+;; Options include optional dictionary for defines and values
+;; and @code{#:inc-dirs} for @code{has_include} etc
 ;; @end deffn
-(define* (eval-cpp-expr tree dict #:key (inc-dirs '()))
+(define* (eval-cpp-expr tree #:optional (dict '()) #:key (inc-dirs '()))
   (letrec
       ((tx (lambda (tr ix) (sx-ref tr ix)))
        (tx1 (lambda (tr) (tx tr 1)))
@@ -545,11 +549,11 @@
 
 ;; === exports =======================
 
-;; @deffn {Procedure} eval-cpp-cond-text text defs => string
+;; @deffn {Procedure} eval-cpp-cond-text text [defs] => string
 ;; Evaluate CPP condition expression (text).
 ;; Undefined identifiers are replaced with @code{0}.
 ;; @end deffn
-(define* (eval-cpp-cond-text text defs #:key (inc-dirs '()))
+(define* (eval-cpp-cond-text text #:optional (defs '()) #:key (inc-dirs '()))
   (with-throw-handler
    'cpp-error
    (lambda ()
@@ -572,16 +576,17 @@
 ;; @end example
 ;; @end deffn
 (define* (expand-cpp-macro-ref ident defs #:optional (used '()))
-  ;;(sferr "x-mref ~S\n" ident)
+  ;;(sferr "x-mref ~S  used=~S\n" ident used)
   (let ((rval (assoc-ref defs ident)))
     (cond
      ((member ident used) #f)
      ((string? rval)
       (let* ((used (cons ident used))
 	     (repl (cpp-expand-text rval defs used)))
-	;;(sferr "rerun ~S\n" repl)
+	;;(sferr "rerun ~S => ~S\n" repl (ident-like? repl))
 	(if (ident-like? repl)
-	    (or (expand-cpp-macro-ref repl defs (cons repl used)) repl)
+	    ;; between 0.80.4 and 0.82.1 I had (cons repl used)
+	    (or (expand-cpp-macro-ref repl defs used) repl)
 	    repl)))
      ((pair? rval)
       (and=> (collect-args (car rval) defs used)
